@@ -35,7 +35,7 @@ static int get_month(const char *month)
 	const char *months[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec", NULL};
 	for (iter = 0; months[iter]; iter++) {
-		if (strcmp(month, months[iter]) == 0)
+		if (purple_strequal(month, months[iter]))
 			break;
 	}
 	return iter;
@@ -635,7 +635,7 @@ static GList *msn_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 	g_return_val_if_fail(sn != NULL, NULL);
 	g_return_val_if_fail(account != NULL, NULL);
 
-	if (strcmp(account->protocol_id, "prpl-msn"))
+	if (!purple_strequal(account->protocol_id, "prpl-msn"))
 		return NULL;
 
 	logdir = purple_prefs_get_string("/plugins/core/log_reader/msn/log_directory");
@@ -783,7 +783,7 @@ static GList *msn_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 				}
 
 				path = g_build_filename(path, name, NULL);
-				if (!strcmp(c, ".xml") &&
+				if (purple_strequal(c, ".xml") &&
 				    g_file_test(path, G_FILE_TEST_EXISTS)) {
 					found = TRUE;
 					g_free(logfile);
@@ -845,7 +845,7 @@ static GList *msn_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 			continue;
 		}
 
-		if (strcmp(session_id, old_session_id)) {
+		if (!purple_strequal(session_id, old_session_id)) {
 			/*
 			 * The session ID differs from the last message.
 			 * Thus, this is the start of a new conversation.
@@ -935,7 +935,7 @@ static char * msn_logger_read (PurpleLog *log, PurpleLogReadFlags *flags)
 			break;
 		}
 
-		if (strcmp(new_session_id, data->session_id)) {
+		if (!purple_strequal(new_session_id, data->session_id)) {
 			/* The session ID differs from the first message.
 			 * Thus, this is the start of a new conversation.
 			 */
@@ -1422,10 +1422,16 @@ static char * trillian_logger_read (PurpleLog *log, PurpleLogReadFlags *flags)
 
 	purple_debug_info("Trillian log read", "Reading %s\n", data->path);
 
+	file = g_fopen(data->path, "rb");
+	g_return_val_if_fail(file != NULL, g_strdup(""));
+
 	read = g_malloc(data->length + 2);
 
-	file = g_fopen(data->path, "rb");
-	fseek(file, data->offset, SEEK_SET);
+	if (fseek(file, data->offset, SEEK_SET) != 0) {
+		fclose(file);
+		g_free(read);
+		g_return_val_if_reached(g_strdup(""));
+	}
 	data->length = fread(read, 1, data->length, file);
 	fclose(file);
 
@@ -1539,7 +1545,7 @@ static char * trillian_logger_read (PurpleLog *log, PurpleLogReadFlags *flags)
 			line = temp->str;
 		}
 
-		if (*line == '[') {
+		if (line && *line == '[') {
 			const char *timestamp;
 
 			if ((timestamp = strchr(line, ']'))) {
@@ -1677,7 +1683,8 @@ static char * trillian_logger_read (PurpleLog *log, PurpleLogReadFlags *flags)
 			}
 		}
 
-		g_string_append(formatted, line);
+		if (line)
+			g_string_append(formatted, line);
 
 		line = c;
 		if (temp)
@@ -1779,8 +1786,10 @@ static GList *qip_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 	g_return_val_if_fail(sn != NULL, NULL);
 	g_return_val_if_fail(account != NULL, NULL);
 
+	memset(&tm, 0, sizeof(tm));
+
 	/* QIP only supports ICQ. */
-	if (strcmp(account->protocol_id, "prpl-icq"))
+	if (!purple_strequal(account->protocol_id, "prpl-icq"))
 		return NULL;
 
 	logdir = purple_prefs_get_string("/plugins/core/log_reader/qip/log_directory");
@@ -1832,10 +1841,13 @@ static GList *qip_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 
 				/* find EOL */
 				c = strchr(c, '\n');
-				c++;
+				if (c)
+					c++;
 
 				/* Find the last '(' character. */
-				if ((tmp = strchr(c, '\n')) != NULL) {
+				if (!c) {
+					/* do nothing */
+				} else if ((tmp = strchr(c, '\n')) != NULL) {
 					while (*tmp && *tmp != '(') --tmp;
 					c = tmp;
 				} else {
@@ -1944,7 +1956,11 @@ static char *qip_logger_read(PurpleLog *log, PurpleLogReadFlags *flags)
 
 	contents = g_malloc(data->length + 2);
 
-	fseek(file, data->offset, SEEK_SET);
+	if (fseek(file, data->offset, SEEK_SET) != 0) {
+		fclose(file);
+		g_free(contents);
+		g_return_val_if_reached(g_strdup(""));
+	}
 	data->length = fread(contents, 1, data->length, file);
 	fclose(file);
 
@@ -1987,6 +2003,8 @@ static char *qip_logger_read(PurpleLog *log, PurpleLogReadFlags *flags)
 
 			/* find EOL */
 			c = strchr(c, '\n');
+			if (!c)
+				break;
 
 			/* XXX: Do we need buddy_name when we have buddy->alias? */
 			buddy_name = ++c;
@@ -2046,7 +2064,9 @@ static char *qip_logger_read(PurpleLog *log, PurpleLogReadFlags *flags)
 
 					/* find EOF */
 					c = strchr(c, '\n');
-					line = ++c;
+					if (c)
+						c++;
+					line = c;
 				}
 			}
 		} else {
@@ -2190,7 +2210,8 @@ static GList *amsn_logger_parse_file(char *filename, const char *sn, PurpleAccou
 				                  sn, data->path, data->offset, data->length);
 			}
 			c = strchr(c, '\n');
-			c++;
+			if (c)
+				c++;
 		}
 
 		/* I've seen the file end without the AMSN_LOG_CONV_END bit */
@@ -2240,7 +2261,7 @@ static GList *amsn_logger_list(PurpleLogType type, const char *sn, PurpleAccount
 		return NULL;
 
 	/* aMSN only works with MSN/WLM */
-	if (strcmp(account->protocol_id, "prpl-msn"))
+	if (!purple_strequal(account->protocol_id, "prpl-msn"))
 		return NULL;
 
 	username = g_strdup(purple_normalize(account, account->username));
@@ -2322,12 +2343,16 @@ static char *amsn_logger_read(PurpleLog *log, PurpleLogReadFlags *flags)
 	g_return_val_if_fail(data->path != NULL, g_strdup(""));
 	g_return_val_if_fail(data->length > 0, g_strdup(""));
 
-	contents = g_malloc(data->length + 2);
-
 	file = g_fopen(data->path, "rb");
 	g_return_val_if_fail(file != NULL, g_strdup(""));
 
-	fseek(file, data->offset, SEEK_SET);
+	contents = g_malloc(data->length + 2);
+
+	if (fseek(file, data->offset, SEEK_SET) != 0) {
+		fclose(file);
+		free(contents);
+		g_return_val_if_reached(g_strdup(""));
+	}
 	data->length = fread(contents, 1, data->length, file);
 	fclose(file);
 
