@@ -373,9 +373,9 @@ void bonjour_jabber_process_packet(PurpleBuddy *pb, xmlnode *packet) {
 	g_return_if_fail(packet != NULL);
 	g_return_if_fail(pb != NULL);
 
-	if (g_strcmp0(packet->name, "message") == 0)
+	if (purple_strequal(packet->name, "message"))
 		_jabber_parse_and_write_message_to_ui(packet, pb);
-	else if (g_strcmp0(packet->name, "iq") == 0)
+	else if (purple_strequal(packet->name, "iq"))
 		xep_iq_parse(packet, pb);
 	else {
 		purple_debug_warning("bonjour", "Unknown packet: %s\n",
@@ -1155,7 +1155,7 @@ bonjour_jabber_close_conversation(BonjourJabberConversation *bconv)
 				tmp_next = xfers->next;
 				/* We only need to cancel this if it hasn't actually started transferring. */
 				/* This will change if we ever support IBB transfers. */
-				if (strcmp(xfer->who, purple_buddy_get_name(bconv->pb)) == 0
+				if (purple_strequal(xfer->who, purple_buddy_get_name(bconv->pb))
 						&& (purple_xfer_get_status(xfer) == PURPLE_XFER_STATUS_NOT_STARTED
 							|| purple_xfer_get_status(xfer) == PURPLE_XFER_STATUS_UNKNOWN)) {
 					purple_xfer_cancel_remote(xfer);
@@ -1169,7 +1169,7 @@ bonjour_jabber_close_conversation(BonjourJabberConversation *bconv)
 			/* Send the end of the stream to the other end of the conversation */
 			if (bconv->sent_stream_start == FULLY_SENT) {
 				size_t len = strlen(STREAM_END);
-				if (send(bconv->socket, STREAM_END, len, 0) != len) {
+				if (send(bconv->socket, STREAM_END, len, 0) != (gssize)len) {
 					purple_debug_error("bonjour",
 						"bonjour_jabber_close_conversation: "
 						"couldn't send data\n");
@@ -1320,8 +1320,8 @@ xep_iq_parse(xmlnode *packet, PurpleBuddy *pb)
 	if(check_if_blocked(pb))
 		return;
 
-		account = purple_buddy_get_account(pb);
-		gc = purple_account_get_connection(account);
+	account = purple_buddy_get_account(pb);
+	gc = purple_account_get_connection(account);
 
 	if (xmlnode_get_child(packet, "si") != NULL || xmlnode_get_child(packet, "error") != NULL)
 		xep_si_parse(gc, packet, pb);
