@@ -93,7 +93,7 @@ silcpurple_buddy_keyagr_cb(SilcClient client,
 								NULL, NULL, key, a->responder);
 			silc_ske_free_key_material(key);
 
-			
+
 			/* Open IM window */
 			convo = purple_find_conversation_with_account(PURPLE_CONV_TYPE_IM,
 									client_entry->nickname, sg->account);
@@ -891,7 +891,7 @@ silcpurple_add_buddy_save(bool success, void *context)
 		silc_free(verifyd);
 	}
 
-	if (serversign.data && !strcmp(serverpk.type, "silc-rsa")) {
+	if (serversign.data && purple_strequal(serverpk.type, "silc-rsa")) {
 		SilcPublicKey public_key;
 		SilcPKCS pkcs;
 		unsigned char *verifyd;
@@ -983,10 +983,10 @@ silcpurple_add_buddy_save(bool success, void *context)
 						      usericon.mime_len);
 			if (m) {
 				const char *type = silc_mime_get_field(m, "Content-Type");
-				if (!strcmp(type, "image/jpeg") ||
-				    !strcmp(type, "image/gif") ||
-				    !strcmp(type, "image/bmp") ||
-				    !strcmp(type, "image/png")) {
+				if (purple_strequal(type, "image/jpeg") ||
+				    purple_strequal(type, "image/gif") ||
+				    purple_strequal(type, "image/bmp") ||
+				    purple_strequal(type, "image/png")) {
 					const unsigned char *data;
 					SilcUInt32 data_len;
 					data = silc_mime_get_data(m, &data_len);
@@ -1176,7 +1176,7 @@ silcpurple_add_buddy_select(SilcPurpleBuddyRes r,
 			   clients[i]->username, clients[i]->hostname ?
 			   clients[i]->hostname : "",
 			   fingerprint ? tmp2 : "");
-		purple_request_field_list_add(f, tmp, clients[i]);
+		purple_request_field_list_add_icon(f, tmp, NULL, clients[i]);
 		silc_free(fingerprint);
 	}
 
@@ -1390,7 +1390,12 @@ silcpurple_add_buddy_i(PurpleConnection *gc, PurpleBuddy *b, gboolean init)
 
 void silcpurple_add_buddy(PurpleConnection *gc, PurpleBuddy *buddy, PurpleGroup *group)
 {
-	silcpurple_add_buddy_i(gc, buddy, FALSE);
+	/* Don't add if the buddy is already on the list.
+	 *
+	 * SILC doesn't have groups, so we don't need to do anything
+	 * for a move. */
+	if (purple_buddy_get_protocol_data(buddy) == NULL)
+		silcpurple_add_buddy_i(gc, buddy, FALSE);
 }
 
 void silcpurple_send_buddylist(PurpleConnection *gc)
@@ -1722,11 +1727,11 @@ void silcpurple_buddy_set_icon(PurpleConnection *gc, PurpleStoredImage *img)
 		return;
 
 	t = purple_imgstore_get_extension(img);
-	if (!t || !strcmp(t, "icon")) {
+	if (!t || purple_strequal(t, "icon")) {
 		silc_mime_free(mime);
 		return;
 	}
-	if (!strcmp(t, "jpg"))
+	if (purple_strequal(t, "jpg"))
 		t = "jpeg";
 	g_snprintf(type, sizeof(type), "image/%s", t);
 	silc_mime_add_field(mime, "Content-Type", type);
@@ -1734,7 +1739,7 @@ void silcpurple_buddy_set_icon(PurpleConnection *gc, PurpleStoredImage *img)
 
 	obj.mime = icon = silc_mime_encode(mime, &obj.mime_len);
 	if (obj.mime)
-		silc_client_attribute_add(client, conn, 
+		silc_client_attribute_add(client, conn,
 					  SILC_ATTRIBUTE_USER_ICON, &obj, sizeof(obj));
 
 	silc_free(icon);
