@@ -94,7 +94,7 @@ silcpurple_mime_message(SilcClient client, SilcClientConnection conn,
 		SilcDList parts = silc_mime_get_multiparts(mime, &mtype);
 
 		/* Only "mixed" type supported */
-		if (strcmp(mtype, "mixed"))
+		if (!purple_strequal(mtype, "mixed"))
 			goto out;
 
 		silc_dlist_start(parts);
@@ -124,7 +124,7 @@ silcpurple_mime_message(SilcClient client, SilcClientConnection conn,
 
 		if (channel)
 			silc_channel_message(client, conn, sender, channel,
-					     payload, key, 
+					     payload, key,
 					     SILC_MESSAGE_FLAG_UTF8, data,
 					     data_len);
 		else
@@ -165,11 +165,11 @@ silcpurple_mime_message(SilcClient client, SilcClientConnection conn,
 		if (imgid) {
 			cflags |= PURPLE_MESSAGE_IMAGES | PURPLE_MESSAGE_RECV;
 			g_snprintf(tmp, sizeof(tmp), "<IMG ID=\"%d\">", imgid);
-		  
+
 			if (channel)
 				serv_got_chat_in(gc, purple_conv_chat_get_id(PURPLE_CONV_CHAT(convo)),
 				 		 sender->nickname ?
-				 		  sender->nickname : 
+				 		  sender->nickname :
 						 "<unknown>", cflags,
 						 tmp, time(NULL));
 			else
@@ -265,8 +265,8 @@ silc_channel_message(SilcClient client, SilcClientConnection conn,
 		    &data_len))
 			return;
 
-		if (!strcmp(type, "application/x-wb") &&
-		    !strcmp(enc, "binary") &&
+		if (purple_strequal(type, "application/x-wb") &&
+		    purple_strequal(enc, "binary") &&
 		    !purple_account_get_bool(sg->account, "block-wb", FALSE))
 			silcpurple_wb_receive_ch(client, conn, sender, channel,
 					       payload, flags, data, data_len);
@@ -364,12 +364,12 @@ silc_private_message(SilcClient client, SilcClientConnection conn,
 		memset(enc, 0, sizeof(enc));
 
 		if (!silc_mime_parse(message, message_len, NULL, 0,
-		    type, sizeof(type) - 1, enc, sizeof(enc) - 1, &data, 
+		    type, sizeof(type) - 1, enc, sizeof(enc) - 1, &data,
 		    &data_len))
 			return;
 
-		if (!strcmp(type, "application/x-wb") &&
-		    !strcmp(enc, "binary") &&
+		if (purple_strequal(type, "application/x-wb") &&
+		    purple_strequal(enc, "binary") &&
 		    !purple_account_get_bool(sg->account, "block-wb", FALSE))
 			silcpurple_wb_receive(client, conn, sender, payload,
 					    flags, data, data_len);
@@ -588,7 +588,7 @@ silc_notify(SilcClient client, SilcClientConnection conn,
 		client_entry = va_arg(va, SilcClientEntry);
 		client_entry2 = va_arg(va, SilcClientEntry);
 
-		if (!strcmp(client_entry->nickname, client_entry2->nickname))
+		if (purple_strequal(client_entry->nickname, client_entry2->nickname))
 			break;
 
 		/* Change nick on all channels */
@@ -890,7 +890,7 @@ silc_notify(SilcClient client, SilcClientConnection conn,
 							if (b->account != gc->account)
 								continue;
 							f = purple_blist_node_get_string(bnode, "public-key");
-							if (f && !strcmp(f, buf))
+							if (f && purple_strequal(f, buf))
 								goto cont;
 							b = NULL;
 						}
@@ -976,7 +976,7 @@ silc_command(SilcClient client, SilcClientConnection conn,
 
 	case SILC_COMMAND_CMODE:
 		if (cmd_context->argc == 3 &&
-		    !strcmp((char *)cmd_context->argv[2], "+C"))
+		    purple_strequal((char *)cmd_context->argv[2], "+C"))
 			sg->chpk = TRUE;
 		else
 			sg->chpk = FALSE;
@@ -1426,7 +1426,7 @@ silc_command_reply(SilcClient client, SilcClientConnection conn,
 				if (!convo)
 					continue;
 				oldnick = purple_conv_chat_get_nick(PURPLE_CONV_CHAT(convo));
-				if (strcmp(oldnick, purple_normalize(purple_conversation_get_account(convo), local_entry->nickname))) {
+				if (!purple_strequal(oldnick, purple_normalize(purple_conversation_get_account(convo), local_entry->nickname))) {
 					purple_conv_chat_rename_user(PURPLE_CONV_CHAT(convo),
 							oldnick, local_entry->nickname);
 					purple_conv_chat_set_nick(PURPLE_CONV_CHAT(convo), local_entry->nickname);
@@ -1444,7 +1444,7 @@ silc_command_reply(SilcClient client, SilcClientConnection conn,
 			int usercount;
 			PurpleRoomlistRoom *room;
 
-			if (sg->roomlist_canceled)
+			if (sg->roomlist_cancelled)
 				break;
 
 			if (!success) {
