@@ -10,6 +10,7 @@
  */
 
 #include "internal.h"
+#include "util.h"
 
 static Code_t Z_RetSubs(ZNotice_t *notice, int *nsubs, Z_AuthProc auth_routine);
 
@@ -105,12 +106,12 @@ static Code_t Z_RetSubs(notice, nsubs, auth_routine)
 		}
 		/* non-matching protocol version numbers means the
 		   server is probably an older version--must punt */
-		if (strcmp(notice->z_version,retnotice.z_version)) {
+		if (!purple_strequal(notice->z_version,retnotice.z_version)) {
 			ZFreeNotice(&retnotice);
 			return(ZERR_VERS);
 		}
 		if (retnotice.z_kind == SERVACK &&
-		    !strcmp(retnotice.z_opcode,notice->z_opcode)) {
+		    purple_strequal(retnotice.z_opcode,notice->z_opcode)) {
 			ZFreeNotice(&retnotice);
 			gimmeack = 1;
 			continue;
@@ -132,6 +133,7 @@ static Code_t Z_RetSubs(notice, nsubs, auth_routine)
 
 		__subscriptions_num = __subscriptions_num / 3;
 
+		free(__subscriptions_list);
 		__subscriptions_list = (ZSubscription_t *)
 			malloc((unsigned)(__subscriptions_num*
 					  sizeof(ZSubscription_t)));
