@@ -1044,7 +1044,7 @@ pidgin_notify_searchresults(PurpleConnection *gc, const char *title,
 		switch (b->type) {
 			case PURPLE_NOTIFY_BUTTON_LABELED:
 				if(b->label) {
-					button = gtk_button_new_with_label(b->label);
+					button = gtk_dialog_add_button(GTK_DIALOG(window), b->label, GTK_RESPONSE_NONE);
 				} else {
 					purple_debug_warning("gtknotify", "Missing button label\n");
 				}
@@ -1284,13 +1284,7 @@ pidgin_notify_uri(const char *uri)
 	GSList *argv = NULL, *argv_remote = NULL;
 	gchar **usercmd_argv = NULL;
 
-	/* Replace some special characters like $ with their percent-encoded
-	   value. This shouldn't be necessary because we shell-escape the entire
-	   arg before exec'ing the browser, however, we had a report that a URL
-	   containing $(xterm) was causing xterm to start on his system. This is
-	   obviously a bug on his system, but it's pretty easy for us to protect
-	   against it. */
-	uri_escaped = g_uri_escape_string(uri, ":;/%#,+?=&@", FALSE);
+	uri_escaped = purple_uri_escape_for_open(uri);
 
 	web_browser = purple_prefs_get_string(PIDGIN_PREFS_ROOT
 		"/browsers/browser");
@@ -1308,8 +1302,8 @@ pidgin_notify_uri(const char *uri)
 	} else if (purple_running_osx() == TRUE) {
 		argv = g_slist_append(argv, "open");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "epiphany") ||
-		!strcmp(web_browser, "galeon"))
+	} else if (purple_strequal(web_browser, "epiphany") ||
+		purple_strequal(web_browser, "galeon"))
 	{
 		argv = g_slist_append(argv, (gpointer)web_browser);
 
@@ -1319,13 +1313,13 @@ pidgin_notify_uri(const char *uri)
 			argv = g_slist_append(argv, "-n");
 
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "xdg-open")) {
+	} else if (purple_strequal(web_browser, "xdg-open")) {
 		argv = g_slist_append(argv, "xdg-open");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "gnome-open")) {
+	} else if (purple_strequal(web_browser, "gnome-open")) {
 		argv = g_slist_append(argv, "gnome-open");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "kfmclient")) {
+	} else if (purple_strequal(web_browser, "kfmclient")) {
 		argv = g_slist_append(argv, "kfmclient");
 		argv = g_slist_append(argv, "openURL");
 		argv = g_slist_append(argv, uri_escaped);
@@ -1333,10 +1327,10 @@ pidgin_notify_uri(const char *uri)
 		 * Does Konqueror have options to open in new tab
 		 * and/or current window?
 		 */
-	} else if (!strcmp(web_browser, "mozilla") ||
-		!strcmp(web_browser, "mozilla-firebird") ||
-		!strcmp(web_browser, "firefox") ||
-		!strcmp(web_browser, "seamonkey"))
+	} else if (purple_strequal(web_browser, "mozilla") ||
+		purple_strequal(web_browser, "mozilla-firebird") ||
+		purple_strequal(web_browser, "firefox") ||
+		purple_strequal(web_browser, "seamonkey"))
 	{
 		argv = g_slist_append(argv, (gpointer)web_browser);
 		argv = g_slist_append(argv, uri_escaped);
@@ -1365,7 +1359,7 @@ pidgin_notify_uri(const char *uri)
 			 * should probably be split apart from mozilla-firebird
 			 * and mozilla... but this is good for now.
 			 */
-			if (!strcmp(web_browser, "firefox")) {
+			if (purple_strequal(web_browser, "firefox")) {
 				argv_remote = g_slist_append(argv_remote, "-a");
 				argv_remote = g_slist_append(argv_remote,
 					"firefox");
@@ -1374,7 +1368,7 @@ pidgin_notify_uri(const char *uri)
 			argv_remote = g_slist_append(argv_remote, "-remote");
 			argv_remote = g_slist_append(argv_remote, uri_custom);
 		}
-	} else if (!strcmp(web_browser, "netscape")) {
+	} else if (purple_strequal(web_browser, "netscape")) {
 		argv = g_slist_append(argv, "netscape");
 		argv = g_slist_append(argv, uri_escaped);
 
@@ -1391,7 +1385,7 @@ pidgin_notify_uri(const char *uri)
 			argv_remote = g_slist_append(argv_remote, "-remote");
 			argv_remote = g_slist_append(argv_remote, uri_custom);
 		}
-	} else if (!strcmp(web_browser, "opera")) {
+	} else if (purple_strequal(web_browser, "opera")) {
 		argv = g_slist_append(argv, "opera");
 
 		if (place == PIDGIN_BROWSER_NEW_WINDOW)
@@ -1405,28 +1399,28 @@ pidgin_notify_uri(const char *uri)
 		 */
 
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "google-chrome")) {
+	} else if (purple_strequal(web_browser, "google-chrome")) {
 		/* Google Chrome doesn't have command-line arguments that
 		 * control the opening of links from external calls. This is
 		 * controlled solely from a preference within Google Chrome.
 		 */
 		argv = g_slist_append(argv, "google-chrome");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "chrome")) {
+	} else if (purple_strequal(web_browser, "chrome")) {
 		/* Chromium doesn't have command-line arguments that control
 		 * the opening of links from external calls. This is controlled
 		 * solely from a preference within Chromium.
 		 */
 		argv = g_slist_append(argv, "chrome");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "chromium-browser")) {
+	} else if (purple_strequal(web_browser, "chromium-browser")) {
 		/* Chromium doesn't have command-line arguments that control the
 		 * opening of links from external calls. This is controlled
 		 * solely from a preference within Chromium.
 		 */
 		argv = g_slist_append(argv, "chromium-browser");
 		argv = g_slist_append(argv, uri_escaped);
-	} else if (!strcmp(web_browser, "custom")) {
+	} else if (purple_strequal(web_browser, "custom")) {
 		GError *error = NULL;
 		const char *usercmd_command;
 		gint usercmd_argc, i;
@@ -1706,13 +1700,13 @@ pidgin_create_notification_dialog(PidginNotifyType type)
 			G_CALLBACK(pounce_response_open_ims), NULL);
 	}
 
-	button = gtk_dialog_add_button(GTK_DIALOG(dialog),
-	                               GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	gtk_dialog_add_button(GTK_DIALOG(dialog),
+		GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), 
+	gtk_box_pack_start(GTK_BOX(vbox),
 		pidgin_make_scrollable(spec_dialog->treeview, GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS, GTK_SHADOW_IN, -1, -1),
 		TRUE, TRUE, 2);
 
