@@ -74,7 +74,8 @@ static GSList *gtk_smileys = NULL;
 static void
 pidgin_smiley_destroy(PidginSmiley *smiley)
 {
-	g_object_set_data(G_OBJECT(smiley->smiley), "edit-dialog", NULL);
+	if (smiley->smiley)
+		g_object_set_data(G_OBJECT(smiley->smiley), "edit-dialog", NULL);
 	gtk_widget_destroy(smiley->parent);
 	g_free(smiley->filename);
 	if (smiley->custom_pixbuf)
@@ -150,7 +151,7 @@ void pidgin_smiley_del_from_list(PurpleSmiley *smiley)
 	for (; list; list = list->next) {
 		gtksmiley = (GtkIMHtmlSmiley*)list->data;
 
-		if (strcmp(gtksmiley->smile, purple_smiley_get_shortcut(smiley)))
+		if (!purple_strequal(gtksmiley->smile, purple_smiley_get_shortcut(smiley)))
 			continue;
 
 		gtk_imhtml_smiley_destroy(gtksmiley);
@@ -331,7 +332,7 @@ static void do_add_file_cb(const char *filename, gpointer data)
 
 	g_free(s->filename);
 	s->filename = g_strdup(filename);
-	pixbuf = gdk_pixbuf_new_from_file_at_scale(filename, 64, 64, FALSE, NULL);
+	pixbuf = pidgin_pixbuf_new_from_file_at_scale(filename, 64, 64, FALSE);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(s->smiley_image), pixbuf);
 	if (pixbuf)
 		g_object_unref(G_OBJECT(pixbuf));
@@ -403,7 +404,8 @@ pidgin_smiley_edit(GtkWidget *widget, PurpleSmiley *smiley)
 			smiley ? GTK_STOCK_SAVE : GTK_STOCK_ADD, GTK_RESPONSE_ACCEPT,
 			NULL);
 	s->parent = window;
-	g_object_set_data(G_OBJECT(smiley), "edit-dialog", window);
+	if (smiley)
+		g_object_set_data(G_OBJECT(smiley), "edit-dialog", window);
 
 	gtk_container_set_border_width(GTK_CONTAINER(window), PIDGIN_HIG_BORDER);
 
@@ -505,7 +507,7 @@ pidgin_smiley_editor_set_image(PidginSmiley *editor, GdkPixbuf *image)
 }
 
 void
-pidgin_smiley_editor_set_data(PidginSmiley *editor, gpointer *data, gsize datasize)
+pidgin_smiley_editor_set_data(PidginSmiley *editor, gpointer data, gsize datasize)
 {
 	editor->data = data;
 	editor->datasize = datasize;
@@ -518,9 +520,6 @@ static void delete_foreach(GtkTreeModel *model, GtkTreePath *path,
 		GtkTreeIter *iter, gpointer data)
 {
 	PurpleSmiley *smiley = NULL;
-	SmileyManager *dialog;
-
-	dialog = (SmileyManager*)data;
 
 	gtk_tree_model_get(model, iter,
 			SMILEY, &smiley,
@@ -683,19 +682,102 @@ edit_selected_cb(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoi
 	smiley_edit_iter(data, iter);
 }
 
+static void
+smiley_got_url(PurpleUtilFetchUrlData *url_data, gpointer user_data,
+		const gchar *smileydata, size_t len, const gchar *error_message)
+{
+	SmileyManager *dialog = user_data;
+	FILE *f;
+	gchar *path;
+	size_t wc;
+	PidginSmiley *ps;
+	GdkPixbuf *image;
+
+	if ((error_message != NULL) || (len == 0)) {
+		return;
+	}
+
+	f = purple_mkstemp(&path, TRUE);
+	wc = fwrite(smileydata, len, 1, f);
+	if (wc != 1) {
+		purple_debug_warning("smiley_got_url", "Unable to write smiley data.\n");
+		fclose(f);
+		g_unlink(path);
+		g_free(path);
+		return;
+	}
+	fclose(f);
+
+	image = pidgin_pixbuf_new_from_file(path);
+	g_unlink(path);
+	g_free(path);
+	if (!image)
+		return;
+
+	ps = pidgin_smiley_edit(dialog->window, NULL);
+	pidgin_smiley_editor_set_image(ps, image);
+	pidgin_smiley_editor_set_data(ps, g_memdup(smileydata, len), len);
+}
+
+static void
+smiley_dnd_recv(GtkWidget *widget, GdkDragContext *dc, guint x, guint y,
+		GtkSelectionData *sd, guint info, guint t, gpointer user_data)
+{
+	SmileyManager *dialog = user_data;
+	gchar *name = g_strchomp((gchar *)sd->data);
+
+	if ((sd->length >= 0) && (sd->format == 8)) {
+		/* Well, it looks like the drag event was cool.
+		 * Let's do something with it */
+
+		if (!g_ascii_strncasecmp(name, "file://", 7)) {
+			GError *converr = NULL;
+			gchar *tmp;
+			PidginSmiley *ps;
+			/* It looks like we're dealing with a local file. Let's
+			 * just try and read it */
+			if(!(tmp = g_filename_from_uri(name, NULL, &converr))) {
+				purple_debug_error("smiley dnd", "%s\n",
+						   (converr ? converr->message :
+							"g_filename_from_uri error"));
+				return;
+			}
+			ps = pidgin_smiley_edit(dialog->window, NULL);
+			do_add_file_cb(tmp, ps);
+			if (gtk_image_get_pixbuf(GTK_IMAGE(ps->smiley_image)) == NULL)
+				gtk_dialog_response(GTK_DIALOG(ps->parent), GTK_RESPONSE_CANCEL);
+			g_free(tmp);
+		} else if (!g_ascii_strncasecmp(name, "http://", 7)) {
+			/* Oo, a web drag and drop. This is where things
+			 * will start to get interesting */
+			purple_util_fetch_url(name, TRUE, NULL, FALSE, smiley_got_url, dialog);
+		} else if (!g_ascii_strncasecmp(name, "https://", 8)) {
+			/* purple_util_fetch_url() doesn't support HTTPS */
+			char *tmp = g_strdup(name + 1);
+			tmp[0] = 'h';
+			tmp[1] = 't';
+			tmp[2] = 't';
+			tmp[3] = 'p';
+
+			purple_util_fetch_url(tmp, TRUE, NULL, FALSE, smiley_got_url, dialog);
+			g_free(tmp);
+		}
+
+		gtk_drag_finish(dc, TRUE, FALSE, t);
+	}
+
+	gtk_drag_finish(dc, FALSE, FALSE, t);
+}
+
 static GtkWidget *smiley_list_create(SmileyManager *dialog)
 {
-	GtkWidget *sw;
 	GtkWidget *treeview;
 	GtkTreeSelection *sel;
-
-	sw = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
-			GTK_POLICY_AUTOMATIC,
-			GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-			GTK_SHADOW_IN);
-	gtk_widget_show(sw);
+	GtkTargetEntry te[3] = {
+		{"text/plain", 0, 0},
+		{"text/uri-list", 0, 1},
+		{"STRING", 0, 2}
+	};
 
 	/* Create the list model */
 	dialog->model = gtk_list_store_new(N_COL,
@@ -713,17 +795,21 @@ static GtkWidget *smiley_list_create(SmileyManager *dialog)
 
 	sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 	gtk_tree_selection_set_mode(sel, GTK_SELECTION_MULTIPLE);
-	gtk_container_add(GTK_CONTAINER(sw), treeview);
 
 	g_signal_connect(G_OBJECT(sel), "changed", G_CALLBACK(smile_selected_cb), dialog);
 	g_signal_connect(G_OBJECT(treeview), "row_activated", G_CALLBACK(smiley_edit_cb), dialog);
 
+	gtk_drag_dest_set(treeview,
+	                  GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
+	                  te, G_N_ELEMENTS(te), GDK_ACTION_COPY | GDK_ACTION_MOVE);
+	g_signal_connect(G_OBJECT(treeview), "drag_data_received", G_CALLBACK(smiley_dnd_recv), dialog);
+
 	gtk_widget_show(treeview);
 
 	add_columns(treeview, dialog);
 	populate_smiley_list(dialog);
 
-	return sw;
+	return pidgin_make_scrollable(treeview, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC, GTK_SHADOW_IN, -1, -1);
 }
 
 static void refresh_list()
