@@ -99,19 +99,15 @@ gevo_prpl_get_field(PurpleAccount *account, PurpleBuddy *buddy)
 
 	protocol_id = purple_account_get_protocol_id(account);
 
-	if (!strcmp(protocol_id, "prpl-aim"))
+	if (purple_strequal(protocol_id, "prpl-aim"))
 		protocol_field = E_CONTACT_IM_AIM;
-	else if (!strcmp(protocol_id, "prpl-icq"))
+	else if (purple_strequal(protocol_id, "prpl-icq"))
 		protocol_field = E_CONTACT_IM_ICQ;
-	else if (!strcmp(protocol_id, "prpl-msn"))
-		protocol_field = E_CONTACT_IM_MSN;
-	else if (!strcmp(protocol_id, "prpl-yahoo"))
-		protocol_field = E_CONTACT_IM_YAHOO;
-	else if (!strcmp(protocol_id, "prpl-jabber"))
+	else if (purple_strequal(protocol_id, "prpl-jabber"))
 		protocol_field = E_CONTACT_IM_JABBER;
-	else if (!strcmp(protocol_id, "prpl-novell"))
+	else if (purple_strequal(protocol_id, "prpl-novell"))
 		protocol_field = E_CONTACT_IM_GROUPWISE;
-	else if (!strcmp(protocol_id, "prpl-gg"))
+	else if (purple_strequal(protocol_id, "prpl-gg"))
 		protocol_field = E_CONTACT_IM_GADUGADU;
 
 	return protocol_field;
@@ -165,23 +161,5 @@ gevo_get_email_for_buddy(PurpleBuddy *buddy)
 		g_object_unref(contact);
 	}
 
-	if (mail == NULL)
-	{
-		PurpleAccount *account = purple_buddy_get_account(buddy);
-		const char *prpl_id = purple_account_get_protocol_id(account);
-
-		if (!strcmp(prpl_id, "prpl-msn"))
-		{
-			mail = g_strdup(purple_normalize(account,
-										   purple_buddy_get_name(buddy)));
-		}
-		else if (!strcmp(prpl_id, "prpl-yahoo"))
-		{
-			mail = g_strdup_printf("%s@yahoo.com",
-								   purple_normalize(account,
-												  purple_buddy_get_name(buddy)));
-		}
-	}
-
 	return mail;
 }
